@@ -510,7 +510,7 @@ close_read_ready (GObject      *source_object,
 {
   GInputStream *stream;
   GVfsJob      *job;
-  GError       *error;
+  GError       *error = NULL;
   gboolean      res;
 
   job = G_VFS_JOB (user_data);
@@ -685,6 +685,13 @@ try_query_info (GVfsBackend           *backend,
   SoupMessage *msg;
   SoupURI     *uri;
 
+  if (g_file_attribute_matcher_matches_only (attribute_matcher,
+                                             G_FILE_ATTRIBUTE_THUMBNAIL_PATH))
+    {
+      g_vfs_job_succeeded (G_VFS_JOB (job));
+      return TRUE;
+    }
+
   uri = http_backend_get_mount_base (backend);
   msg = soup_message_new_from_uri (SOUP_METHOD_HEAD, uri);
 
